@@ -9,6 +9,9 @@ types: list[str] = [
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
+    "AWS::AmazonMQ::Broker",
+    "AWS::AmazonMQ::Configuration",
+    "AWS::AmazonMQ::ConfigurationAssociation",
     "AWS::ApiGateway::Account",
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
@@ -30,6 +33,18 @@ types: list[str] = [
     "AWS::ApiGateway::Stage",
     "AWS::ApiGateway::UsagePlan",
     "AWS::ApiGateway::UsagePlanKey",
+    "AWS::ApiGatewayV2::Api",
+    "AWS::ApiGatewayV2::ApiGatewayManagedOverrides",
+    "AWS::ApiGatewayV2::ApiMapping",
+    "AWS::ApiGatewayV2::Authorizer",
+    "AWS::ApiGatewayV2::Deployment",
+    "AWS::ApiGatewayV2::DomainName",
+    "AWS::ApiGatewayV2::IntegrationResponse",
+    "AWS::ApiGatewayV2::Model",
+    "AWS::ApiGatewayV2::Route",
+    "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::Stage",
+    "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
     "AWS::AppConfig::ConfigurationProfile",
     "AWS::AppConfig::Deployment",
@@ -54,6 +69,7 @@ types: list[str] = [
     "AWS::Backup::BackupSelection",
     "AWS::Backup::BackupVault",
     "AWS::Batch::ComputeEnvironment",
+    "AWS::Batch::ConsumableResource",
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
@@ -75,8 +91,10 @@ types: list[str] = [
     "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
+    "AWS::CloudFront::ConnectionGroup",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
     "AWS::CloudFront::Distribution",
+    "AWS::CloudFront::DistributionTenant",
     "AWS::CloudFront::Function",
     "AWS::CloudFront::KeyGroup",
     "AWS::CloudFront::KeyValueStore",
@@ -92,11 +110,27 @@ types: list[str] = [
     "AWS::CloudWatch::CompositeAlarm",
     "AWS::CloudWatch::Dashboard",
     "AWS::CloudWatch::InsightRule",
+    "AWS::CloudWatch::MetricStream",
     "AWS::CodeDeploy::Application",
     "AWS::CodeDeploy::DeploymentConfig",
     "AWS::CodeDeploy::DeploymentGroup",
     "AWS::CodePipeline::CustomActionType",
     "AWS::CodePipeline::Pipeline",
+    "AWS::Cognito::IdentityPool",
+    "AWS::Cognito::IdentityPoolPrincipalTag",
+    "AWS::Cognito::IdentityPoolRoleAttachment",
+    "AWS::Cognito::LogDeliveryConfiguration",
+    "AWS::Cognito::ManagedLoginBranding",
+    "AWS::Cognito::UserPool",
+    "AWS::Cognito::UserPoolClient",
+    "AWS::Cognito::UserPoolDomain",
+    "AWS::Cognito::UserPoolGroup",
+    "AWS::Cognito::UserPoolIdentityProvider",
+    "AWS::Cognito::UserPoolResourceServer",
+    "AWS::Cognito::UserPoolRiskConfigurationAttachment",
+    "AWS::Cognito::UserPoolUICustomizationAttachment",
+    "AWS::Cognito::UserPoolUser",
+    "AWS::Cognito::UserPoolUserToGroupAttachment",
     "AWS::Config::AggregationAuthorization",
     "AWS::Config::ConfigRule",
     "AWS::Config::ConfigurationAggregator",
@@ -106,10 +140,15 @@ types: list[str] = [
     "AWS::ControlTower::EnabledBaseline",
     "AWS::ControlTower::EnabledControl",
     "AWS::ControlTower::LandingZone",
+    "AWS::DLM::LifecyclePolicy",
     "AWS::DataPipeline::Pipeline",
     "AWS::DataSync::Agent",
     "AWS::DataSync::LocationAzureBlob",
     "AWS::DataSync::LocationEFS",
+    "AWS::DataSync::LocationFSxLustre",
+    "AWS::DataSync::LocationFSxONTAP",
+    "AWS::DataSync::LocationFSxOpenZFS",
+    "AWS::DataSync::LocationFSxWindows",
     "AWS::DataSync::LocationHDFS",
     "AWS::DataSync::LocationNFS",
     "AWS::DataSync::LocationObjectStorage",
@@ -161,6 +200,10 @@ types: list[str] = [
     "AWS::EC2::SubnetCidrBlock",
     "AWS::EC2::SubnetNetworkAclAssociation",
     "AWS::EC2::SubnetRouteTableAssociation",
+    "AWS::EC2::TrafficMirrorFilter",
+    "AWS::EC2::TrafficMirrorFilterRule",
+    "AWS::EC2::TrafficMirrorSession",
+    "AWS::EC2::TrafficMirrorTarget",
     "AWS::EC2::TransitGateway",
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
@@ -242,14 +285,39 @@ types: list[str] = [
     "AWS::Elasticsearch::Domain",
     "AWS::Events::EventBus",
     "AWS::Events::Rule",
+    "AWS::FMS::NotificationChannel",
+    "AWS::FMS::Policy",
+    "AWS::FMS::ResourceSet",
+    "AWS::FSx::DataRepositoryAssociation",
+    "AWS::FSx::FileSystem",
+    "AWS::FSx::Snapshot",
+    "AWS::FSx::StorageVirtualMachine",
+    "AWS::FSx::Volume",
     "AWS::GameLift::Alias",
     "AWS::GameLift::Build",
     "AWS::GameLift::Fleet",
+    "AWS::Glue::Classifier",
+    "AWS::Glue::Connection",
+    "AWS::Glue::Crawler",
+    "AWS::Glue::CustomEntityType",
+    "AWS::Glue::DataCatalogEncryptionSettings",
+    "AWS::Glue::DataQualityRuleset",
+    "AWS::Glue::Database",
+    "AWS::Glue::DevEndpoint",
+    "AWS::Glue::Job",
+    "AWS::Glue::MLTransform",
+    "AWS::Glue::Partition",
+    "AWS::Glue::SecurityConfiguration",
+    "AWS::Glue::Table",
+    "AWS::Glue::Trigger",
+    "AWS::Glue::Workflow",
     "AWS::GuardDuty::Detector",
     "AWS::GuardDuty::Filter",
     "AWS::GuardDuty::IPSet",
+    "AWS::GuardDuty::MalwareProtectionPlan",
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
+    "AWS::GuardDuty::PublishingDestination",
     "AWS::GuardDuty::ThreatIntelSet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
@@ -291,7 +359,10 @@ types: list[str] = [
     "AWS::KinesisAnalyticsV2::Application",
     "AWS::KinesisFirehose::DeliveryStream",
     "AWS::LakeFormation::DataCellsFilter",
+    "AWS::LakeFormation::DataLakeSettings",
+    "AWS::LakeFormation::Permissions",
     "AWS::LakeFormation::PrincipalPermissions",
+    "AWS::LakeFormation::Resource",
     "AWS::LakeFormation::Tag",
     "AWS::LakeFormation::TagAssociation",
     "AWS::Lambda::Alias",
@@ -302,6 +373,7 @@ types: list[str] = [
     "AWS::Lambda::LayerVersionPermission",
     "AWS::Lambda::Permission",
     "AWS::Lambda::Version",
+    "AWS::LaunchWizard::Deployment",
     "AWS::Location::APIKey",
     "AWS::Location::GeofenceCollection",
     "AWS::Location::Map",
@@ -326,11 +398,32 @@ types: list[str] = [
     "AWS::MSK::ClusterPolicy",
     "AWS::MSK::Configuration",
     "AWS::MSK::VpcConnection",
+    "AWS::Neptune::DBCluster",
+    "AWS::Neptune::DBClusterParameterGroup",
+    "AWS::Neptune::DBInstance",
+    "AWS::Neptune::DBParameterGroup",
+    "AWS::Neptune::DBSubnetGroup",
+    "AWS::Neptune::EventSubscription",
     "AWS::NetworkFirewall::Firewall",
     "AWS::NetworkFirewall::FirewallPolicy",
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkManager::ConnectAttachment",
+    "AWS::NetworkManager::ConnectPeer",
+    "AWS::NetworkManager::CoreNetwork",
+    "AWS::NetworkManager::CustomerGatewayAssociation",
+    "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::DirectConnectGatewayAttachment",
+    "AWS::NetworkManager::GlobalNetwork",
+    "AWS::NetworkManager::Link",
+    "AWS::NetworkManager::LinkAssociation",
+    "AWS::NetworkManager::Site",
+    "AWS::NetworkManager::SiteToSiteVpnAttachment",
+    "AWS::NetworkManager::TransitGatewayPeering",
+    "AWS::NetworkManager::TransitGatewayRegistration",
+    "AWS::NetworkManager::TransitGatewayRouteTableAttachment",
+    "AWS::NetworkManager::VpcAttachment",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
     "AWS::OpenSearchService::Domain",
@@ -346,12 +439,22 @@ types: list[str] = [
     "AWS::Organizations::OrganizationalUnit",
     "AWS::Organizations::Policy",
     "AWS::Organizations::ResourcePolicy",
+    "AWS::PCAConnectorAD::Connector",
+    "AWS::PCAConnectorAD::DirectoryRegistration",
+    "AWS::PCAConnectorAD::ServicePrincipalName",
+    "AWS::PCAConnectorAD::Template",
+    "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
+    "AWS::PCAConnectorSCEP::Challenge",
+    "AWS::PCAConnectorSCEP::Connector",
     "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
     "AWS::RDS::DBCluster",
     "AWS::RDS::DBClusterParameterGroup",
     "AWS::RDS::DBInstance",
     "AWS::RDS::DBParameterGroup",
+    "AWS::RDS::DBProxy",
+    "AWS::RDS::DBProxyEndpoint",
+    "AWS::RDS::DBProxyTargetGroup",
     "AWS::RDS::DBSecurityGroup",
     "AWS::RDS::DBSecurityGroupIngress",
     "AWS::RDS::DBSubnetGroup",
@@ -367,8 +470,15 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
+    "AWS::ResourceExplorer2::DefaultViewAssociation",
+    "AWS::ResourceExplorer2::View",
     "AWS::ResourceGroups::Group",
+    "AWS::RolesAnywhere::CRL",
+    "AWS::RolesAnywhere::Profile",
+    "AWS::RolesAnywhere::TrustAnchor",
+    "AWS::Route53::CidrCollection",
     "AWS::Route53::DNSSEC",
     "AWS::Route53::HealthCheck",
     "AWS::Route53::HostedZone",
@@ -378,8 +488,15 @@ types: list[str] = [
     "AWS::Route53Resolver::FirewallDomainList",
     "AWS::Route53Resolver::FirewallRuleGroup",
     "AWS::Route53Resolver::FirewallRuleGroupAssociation",
+    "AWS::Route53Resolver::ResolverConfig",
+    "AWS::Route53Resolver::ResolverEndpoint",
     "AWS::Route53Resolver::ResolverQueryLoggingConfig",
     "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation",
+    "AWS::Route53Resolver::ResolverRule",
+    "AWS::Route53Resolver::ResolverRuleAssociation",
+    "AWS::S3::AccessGrant",
+    "AWS::S3::AccessGrantsInstance",
+    "AWS::S3::AccessGrantsLocation",
     "AWS::S3::AccessPoint",
     "AWS::S3::Bucket",
     "AWS::S3::BucketPolicy",
@@ -401,6 +518,17 @@ types: list[str] = [
     "AWS::SSM::Parameter",
     "AWS::SSM::PatchBaseline",
     "AWS::SSM::ResourceDataSync",
+    "AWS::SSO::Application",
+    "AWS::SSO::ApplicationAssignment",
+    "AWS::SSO::Assignment",
+    "AWS::SSO::Instance",
+    "AWS::SSO::InstanceAccessControlAttributeConfiguration",
+    "AWS::SSO::PermissionSet",
+    "AWS::SageMaker::MlflowTrackingServer",
+    "AWS::SageMaker::ModelCard",
+    "AWS::SageMaker::ModelPackage",
+    "AWS::SageMaker::ModelPackageGroup",
+    "AWS::SageMaker::Pipeline",
     "AWS::SecretsManager::ResourcePolicy",
     "AWS::SecretsManager::RotationSchedule",
     "AWS::SecretsManager::Secret",
@@ -458,6 +586,8 @@ cached: list[str] = [
     "aws-acmpca-certificateauthority.json",
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
+    "aws-amazonmq-broker.json",
+    "aws-amazonmq-configuration.json",
     "aws-apigateway-account.json",
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
@@ -467,6 +597,7 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
+    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
@@ -478,8 +609,20 @@ cached: list[str] = [
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
+    "aws-apigatewayv2-apigatewaymanagedoverrides.json",
+    "aws-apigatewayv2-apimapping.json",
+    "aws-apigatewayv2-authorizer.json",
+    "aws-apigatewayv2-deployment.json",
+    "aws-apigatewayv2-integrationresponse.json",
+    "aws-apigatewayv2-model.json",
+    "aws-apigatewayv2-route.json",
+    "aws-apigatewayv2-routeresponse.json",
+    "aws-apigatewayv2-stage.json",
+    "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
     "aws-appconfig-configurationprofile.json",
+    "aws-appconfig-deployment.json",
+    "aws-appconfig-deploymentstrategy.json",
     "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
@@ -491,11 +634,15 @@ cached: list[str] = [
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
+    "aws-autoscaling-lifecyclehook.json",
+    "aws-autoscaling-scalingpolicy.json",
+    "aws-autoscaling-scheduledaction.json",
     "aws-autoscaling-warmpool.json",
     "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-batch-computeenvironment.json",
+    "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
@@ -514,8 +661,10 @@ cached: list[str] = [
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
     "aws-cloudfront-distribution.json",
+    "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
@@ -531,8 +680,25 @@ cached: list[str] = [
     "aws-cloudwatch-compositealarm.json",
     "aws-cloudwatch-dashboard.json",
     "aws-cloudwatch-insightrule.json",
+    "aws-cloudwatch-metricstream.json",
     "aws-codedeploy-deploymentgroup.json",
+    "aws-cognito-identitypool.json",
+    "aws-cognito-identitypoolprincipaltag.json",
+    "aws-cognito-identitypoolroleattachment.json",
+    "aws-cognito-logdeliveryconfiguration.json",
+    "aws-cognito-managedloginbranding.json",
+    "aws-cognito-userpool.json",
+    "aws-cognito-userpoolclient.json",
+    "aws-cognito-userpooldomain.json",
+    "aws-cognito-userpoolgroup.json",
+    "aws-cognito-userpoolidentityprovider.json",
+    "aws-cognito-userpoolresourceserver.json",
+    "aws-cognito-userpoolriskconfigurationattachment.json",
+    "aws-cognito-userpooluicustomizationattachment.json",
+    "aws-cognito-userpooluser.json",
+    "aws-cognito-userpoolusertogroupattachment.json",
     "aws-config-aggregationauthorization.json",
+    "aws-config-configrule.json",
     "aws-config-configurationaggregator.json",
     "aws-config-configurationrecorder.json",
     "aws-config-deliverychannel.json",
@@ -543,21 +709,28 @@ cached: list[str] = [
     "aws-datasync-agent.json",
     "aws-datasync-locationazureblob.json",
     "aws-datasync-locationefs.json",
+    "aws-datasync-locationfsxlustre.json",
+    "aws-datasync-locationfsxontap.json",
+    "aws-datasync-locationfsxopenzfs.json",
+    "aws-datasync-locationfsxwindows.json",
     "aws-datasync-locationhdfs.json",
     "aws-datasync-locationnfs.json",
     "aws-datasync-locationobjectstorage.json",
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
+    "aws-dlm-lifecyclepolicy.json",
+    "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
-    "aws-ec2-ec2fleet.json",
     "aws-ec2-egressonlyinternetgateway.json",
+    "aws-ec2-eip.json",
     "aws-ec2-eipassociation.json",
     "aws-ec2-flowlog.json",
     "aws-ec2-gatewayroutetableassociation.json",
+    "aws-ec2-instance.json",
     "aws-ec2-internetgateway.json",
     "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
@@ -583,8 +756,13 @@ cached: list[str] = [
     "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
+    "aws-ec2-subnet.json",
     "aws-ec2-subnetcidrblock.json",
+    "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
+    "aws-ec2-trafficmirrorfilter.json",
+    "aws-ec2-trafficmirrorfilterrule.json",
+    "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
@@ -599,6 +777,7 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
     "aws-ec2-volume.json",
+    "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
     "aws-ec2-vpcblockpublicaccessoptions.json",
@@ -608,6 +787,7 @@ cached: list[str] = [
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
+    "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
@@ -641,6 +821,7 @@ cached: list[str] = [
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-serverlesscache.json",
     "aws-elasticache-user.json",
+    "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
@@ -653,13 +834,34 @@ cached: list[str] = [
     "aws-emr-cluster.json",
     "aws-emr-instancefleetconfig.json",
     "aws-emr-instancegroupconfig.json",
+    "aws-emr-step.json",
     "aws-events-eventbus.json",
     "aws-events-rule.json",
+    "aws-fms-notificationchannel.json",
+    "aws-fms-resourceset.json",
+    "aws-fsx-datarepositoryassociation.json",
+    "aws-fsx-filesystem.json",
+    "aws-fsx-snapshot.json",
+    "aws-fsx-storagevirtualmachine.json",
+    "aws-fsx-volume.json",
+    "aws-glue-classifier.json",
+    "aws-glue-connection.json",
+    "aws-glue-customentitytype.json",
+    "aws-glue-datacatalogencryptionsettings.json",
+    "aws-glue-dataqualityruleset.json",
+    "aws-glue-devendpoint.json",
+    "aws-glue-mltransform.json",
+    "aws-glue-partition.json",
+    "aws-glue-securityconfiguration.json",
+    "aws-glue-table.json",
+    "aws-glue-workflow.json",
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
     "aws-guardduty-ipset.json",
+    "aws-guardduty-malwareprotectionplan.json",
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
+    "aws-guardduty-publishingdestination.json",
     "aws-guardduty-threatintelset.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
@@ -693,13 +895,17 @@ cached: list[str] = [
     "aws-kms-key.json",
     "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
+    "aws-lakeformation-datalakesettings.json",
+    "aws-lakeformation-permissions.json",
     "aws-lakeformation-principalpermissions.json",
+    "aws-lakeformation-resource.json",
     "aws-lakeformation-tag.json",
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
+    "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
@@ -715,7 +921,6 @@ cached: list[str] = [
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -727,11 +932,31 @@ cached: list[str] = [
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
     "aws-msk-vpcconnection.json",
+    "aws-neptune-dbcluster.json",
+    "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbparametergroup.json",
+    "aws-neptune-dbsubnetgroup.json",
+    "aws-neptune-eventsubscription.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkmanager-connectattachment.json",
+    "aws-networkmanager-connectpeer.json",
+    "aws-networkmanager-corenetwork.json",
+    "aws-networkmanager-customergatewayassociation.json",
+    "aws-networkmanager-device.json",
+    "aws-networkmanager-directconnectgatewayattachment.json",
+    "aws-networkmanager-globalnetwork.json",
+    "aws-networkmanager-link.json",
+    "aws-networkmanager-linkassociation.json",
+    "aws-networkmanager-site.json",
+    "aws-networkmanager-sitetositevpnattachment.json",
+    "aws-networkmanager-transitgatewaypeering.json",
+    "aws-networkmanager-transitgatewayregistration.json",
+    "aws-networkmanager-transitgatewayroutetableattachment.json",
+    "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-opensearchservice-domain.json",
@@ -744,12 +969,23 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
+    "aws-pcaconnectorad-connector.json",
+    "aws-pcaconnectorad-directoryregistration.json",
+    "aws-pcaconnectorad-serviceprincipalname.json",
+    "aws-pcaconnectorad-template.json",
+    "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
+    "aws-pcaconnectorscep-challenge.json",
+    "aws-pcaconnectorscep-connector.json",
     "aws-ram-permission.json",
+    "aws-ram-resourceshare.json",
     "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
+    "aws-rds-dbproxy.json",
+    "aws-rds-dbproxyendpoint.json",
+    "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
     "aws-rds-dbsubnetgroup.json",
@@ -764,8 +1000,15 @@ cached: list[str] = [
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
+    "aws-resourceexplorer2-defaultviewassociation.json",
+    "aws-resourceexplorer2-view.json",
     "aws-resourcegroups-group.json",
+    "aws-rolesanywhere-crl.json",
+    "aws-rolesanywhere-profile.json",
+    "aws-rolesanywhere-trustanchor.json",
+    "aws-route53-cidrcollection.json",
     "aws-route53-dnssec.json",
     "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
@@ -774,12 +1017,24 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
+    "aws-route53resolver-resolverconfig.json",
+    "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverruleassociation.json",
+    "aws-s3-accessgrant.json",
+    "aws-s3-accessgrantsinstance.json",
+    "aws-s3-accessgrantslocation.json",
+    "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
+    "aws-sagemaker-mlflowtrackingserver.json",
+    "aws-sagemaker-modelcard.json",
+    "aws-sagemaker-modelpackage.json",
+    "aws-sagemaker-modelpackagegroup.json",
+    "aws-sagemaker-pipeline.json",
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
@@ -813,6 +1068,12 @@ cached: list[str] = [
     "aws-ssm-parameter.json",
     "aws-ssm-patchbaseline.json",
     "aws-ssm-resourcedatasync.json",
+    "aws-sso-application.json",
+    "aws-sso-applicationassignment.json",
+    "aws-sso-assignment.json",
+    "aws-sso-instance.json",
+    "aws-sso-instanceaccesscontrolattributeconfiguration.json",
+    "aws-sso-permissionset.json",
     "aws-stepfunctions-activity.json",
     "aws-stepfunctions-statemachine.json",
     "aws-stepfunctions-statemachinealias.json",
@@ -830,8 +1091,6 @@ cached: list[str] = [
     "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-regexpatternset.json",
-    "aws-wafv2-rulegroup.json",
-    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-xray-group.json",
