@@ -17,7 +17,6 @@ import inspect
 import json
 import logging
 import os
-import sys
 from io import BytesIO
 from typing import Any, Sequence
 from urllib.request import Request, urlopen, urlretrieve
@@ -116,6 +115,13 @@ AVAILABILITY_ZONES = {
     "us-gov-west-1": ["us-gov-west-1a", "us-gov-west-1b", "us-gov-west-1c"],
     "us-west-1": ["us-west-1a", "us-west-1c"],
     "us-west-2": ["us-west-2a", "us-west-2b", "us-west-2c", "us-west-2d"],
+    # Isolated regions
+    "us-iso-east-1": ["us-iso-east-1a", "us-iso-east-1b", "us-iso-east-1c"],
+    "us-iso-west-1": ["us-iso-west-1a", "us-iso-west-1b", "us-iso-west-1c"],
+    "us-isob-east-1": ["us-isob-east-1a", "us-isob-east-1b", "us-isob-east-1c"],
+    "us-isof-east-1": ["us-isof-east-1a", "us-isof-east-1b", "us-isof-east-1c"],
+    "us-isof-south-1": ["us-isof-south-1a", "us-isof-south-1b", "us-isof-south-1c"],
+    "eu-isoe-west-1": ["eu-isoe-west-1a", "eu-isoe-west-1b", "eu-isoe-west-1c"],
 }
 
 REGIONS = list(AVAILABILITY_ZONES.keys())
@@ -353,11 +359,12 @@ VALID_PARAMETER_TYPES = list(VALID_PARAMETER_TYPES_SINGLE) + list(
     VALID_PARAMETER_TYPES_LIST
 )
 
-BOOLEAN_STRINGS_TRUE = frozenset(["true", "True"])
-BOOLEAN_STRINGS_FALSE = frozenset(["false", "False"])
+BOOLEAN_STRINGS_TRUE = frozenset(["true", "True", "TRUE"])
+BOOLEAN_STRINGS_FALSE = frozenset(["false", "False", "FALSE"])
 BOOLEAN_STRINGS = frozenset(list(BOOLEAN_STRINGS_TRUE) + list(BOOLEAN_STRINGS_FALSE))
 
 TRANSFORM_SAM = "AWS::Serverless-2016-10-31"
+TRANSFORM_LANGUAGE_EXTENSION = "AWS::LanguageExtensions"
 
 
 # pylint: disable=missing-class-docstring
@@ -517,14 +524,11 @@ def load_resource(package, filename="us-east-1.json"):
     :param filename: filename to load
     :return: Json output of the resource laoded
     """
-    if sys.version_info >= (3, 9):
-        return json.loads(
-            pkg_resources.files(package)  # pylint: disable=no-member
-            .joinpath(filename)
-            .read_text(encoding="utf-8")
-        )
-    # pylint: disable=W4902
-    return json.loads(pkg_resources.read_text(package, filename, encoding="utf-8"))
+    return json.loads(
+        pkg_resources.files(package)  # pylint: disable=no-member
+        .joinpath(filename)
+        .read_text(encoding="utf-8")
+    )
 
 
 def is_custom_resource(resource_type):
